Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Config.

Actions, resources, and condition keys for AWS Config - Service Authorization Reference

# Actions, resources, and condition keys for AWS Config

AWS Config (service prefix: `config` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Config
- Resource types defined by AWS Config
- Condition keys for AWS Config

## Actions defined by AWS Config

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetAggregateResourceConfig | Grants permission to return the current configuration items for resources that are present in your AWS Config aggregator | Read | ConfigurationAggregator* |  |
BatchGetResourceConfig | Grants permission to return the current configuration for one or more requested resources | Read |  |  |
DeleteAggregationAuthorization | Grants permission to delete the authorization granted to the specified configuration aggregator account in a specified region | Write | AggregationAuthorization* |  |
DeleteConfigRule | Grants permission to delete the specified AWS Config rule and all of its evaluation results | Write | ConfigRule* |  |
DeleteConfigurationAggregator | Grants permission to delete the specified configuration aggregator and the aggregated data associated with the aggregator | Write | ConfigurationAggregator* |  |
DeleteConfigurationRecorder | Grants permission to delete the configuration recorder | Write |  |  |
DeleteConformancePack | Grants permission to delete the specified conformance pack and all the AWS Config rules and all evaluation results within that conformance pack | Write | ConformancePack* |  |
DeleteDeliveryChannel | Grants permission to delete the delivery channel | Write |  |  |
DeleteEvaluationResults | Grants permission to delete the evaluation results for the specified Config rule | Write | ConfigRule* |  |
DeleteOrganizationConfigRule | Grants permission to delete the specified organization config rule and all of its evaluation results from all member accounts in that organization | Write | OrganizationConfigRule* |  |
DeleteOrganizationConformancePack | Grants permission to delete the specified organization conformance pack and all of its evaluation results from all member accounts in that organization | Write | OrganizationConformancePack* |  |
DeletePendingAggregationRequest | Grants permission to delete pending authorization requests for a specified aggregator account in a specified region | Write |  |  |
DeleteRemediationConfiguration | Grants permission to delete the remediation configuration | Write | RemediationConfiguration* |  |
DeleteRemediationExceptions | Grants permission to delete one or more remediation exceptions for specific resource keys for a specific AWS Config Rule | Write |  |  |
DeleteResourceConfig | Grants permission to record the configuration state for a custom resource that has been deleted | Write |  |  |
DeleteRetentionConfiguration | Grants permission to delete the retention configuration | Write |  |  |
DeleteStoredQuery | Grants permission to delete the stored query for an AWS account in an AWS Region | Write | StoredQuery* |  |
DeliverConfigSnapshot | Grants permission to schedule delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel | Read |  |  |
DescribeAggregateComplianceByConfigRules | Grants permission to return a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules | Read | ConfigurationAggregator* |  |
DescribeAggregateComplianceByConformancePacks | Grants permission to return a list of compliant and noncompliant conformance packs along with count of compliant, non-compliant and total rules within each conformance pack | Read | ConfigurationAggregator* |  |
DescribeAggregationAuthorizations | Grants permission to return a list of authorizations granted to various aggregator accounts and regions | List |  |  |
DescribeComplianceByConfigRule | Grants permission to indicate whether the specified AWS Config rules are compliant | Read |  |  |
DescribeComplianceByResource | Grants permission to indicate whether the specified AWS resources are compliant | Read |  |  |
DescribeConfigRuleEvaluationStatus | Grants permission to return status information for each of your AWS managed Config rules | Read |  |  |
DescribeConfigRules | Grants permission to return details about your AWS Config rules | List |  |  |
DescribeConfigurationAggregatorSourcesStatus | Grants permission to return status information for sources within an aggregator | Read | ConfigurationAggregator* |  |
DescribeConfigurationAggregators | Grants permission to return the details of one or more configuration aggregators | List |  |  |
DescribeConfigurationRecorderStatus | Grants permission to return the current status of the specified configuration recorder | Read |  |  |
DescribeConfigurationRecorders | Grants permission to return the names of one or more specified configuration recorders | List |  |  |
DescribeConformancePackCompliance | Grants permission to return compliance information for each rule in that conformance pack | Read | ConformancePack* |  |
DescribeConformancePackStatus | Grants permission to provide one or more conformance packs deployment status | Read |  |  |
DescribeConformancePacks | Grants permission to return a list of one or more conformance packs | List |  |  |
DescribeDeliveryChannelStatus | Grants permission to return the current status of the specified delivery channel | Read |  |  |
DescribeDeliveryChannels | Grants permission to return details about the specified delivery channel | List |  |  |
DescribeOrganizationConfigRuleStatuses | Grants permission to provide organization config rule deployment status for an organization | Read |  |  |
DescribeOrganizationConfigRules | Grants permission to return a list of organization config rules | List |  |  |
DescribeOrganizationConformancePackStatuses | Grants permission to provide organization conformance pack deployment status for an organization | Read |  |  |
DescribeOrganizationConformancePacks | Grants permission to return a list of organization conformance packs | List |  |  |
DescribePendingAggregationRequests | Grants permission to return a list of all pending aggregation requests | List |  |  |
DescribeRemediationConfigurations | Grants permission to return the details of one or more remediation configurations | List | RemediationConfiguration* |  |
DescribeRemediationExceptions | Grants permission to return the details of one or more remediation exceptions | List |  |  |
DescribeRemediationExecutionStatus | Grants permission to provide a detailed view of a Remediation Execution for a set of resources including state, timestamps and any error messages for steps that have failed | Read | RemediationConfiguration* |  |
DescribeRetentionConfigurations | Grants permission to return the details of one or more retention configurations | List |  |  |
GetAggregateComplianceDetailsByConfigRule | Grants permission to return the evaluation results for the specified AWS Config rule for a specific resource in a rule | Read | ConfigurationAggregator* |  |
GetAggregateConfigRuleComplianceSummary | Grants permission to return the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator | Read | ConfigurationAggregator* |  |
GetAggregateConformancePackComplianceSummary | Grants permission to return the number of compliant and noncompliant conformance packs for one or more accounts and regions in an aggregator | Read | ConfigurationAggregator* |  |
GetAggregateDiscoveredResourceCounts | Grants permission to return the resource counts across accounts and regions that are present in your AWS Config aggregator | Read | ConfigurationAggregator* |  |
GetAggregateResourceConfig | Grants permission to return configuration item that is aggregated for your specific resource in a specific source account and region | Read | ConfigurationAggregator* |  |
GetComplianceDetailsByConfigRule | Grants permission to return the evaluation results for the specified AWS Config rule | Read | ConfigRule* |  |
GetComplianceDetailsByResource | Grants permission to return the evaluation results for the specified AWS resource | Read |  |  |
GetComplianceSummaryByConfigRule | Grants permission to return the number of AWS Config rules that are compliant and noncompliant, up to a maximum of 25 for each | Read |  |  |
GetComplianceSummaryByResourceType | Grants permission to return the number of resources that are compliant and the number that are noncompliant | Read |  |  |
GetConformancePackComplianceDetails | Grants permission to return compliance details of a conformance pack for all AWS resources that are monitered by conformance pack | Read | ConformancePack* |  |
GetConformancePackComplianceSummary | Grants permission to provide compliance summary for one or more conformance packs | Read | ConformancePack* |  |
GetCustomRulePolicy | Grants permission to return the policy definition containing the logic for your AWS Config Custom Policy rule | Read | ConfigRule* |  |
GetDiscoveredResourceCounts | Grants permission to return the resource types, the number of each resource type, and the total number of resources that AWS Config is recording in this region for your AWS account | Read |  |  |
GetOrganizationConfigRuleDetailedStatus | Grants permission to return detailed status for each member account within an organization for a given organization config rule | Read | OrganizationConfigRule* |  |
GetOrganizationConformancePackDetailedStatus | Grants permission to return detailed status for each member account within an organization for a given organization conformance pack | Read | OrganizationConformancePack* |  |
GetOrganizationCustomRulePolicy | Grants permission to return the policy definition containing the logic for your organization AWS Config Custom Policy rule | Read | OrganizationConfigRule* |  |
GetResourceConfigHistory | Grants permission to return a list of configuration items for the specified resource | Read |  |  |
GetResourceEvaluationSummary | Grants permission to return the summary of resource evaluations for a specific resource evaluation ID | Read |  |  |
GetStoredQuery | Grants permission to return the details of a specific stored query | Read | StoredQuery* |  |
ListAggregateDiscoveredResources | Grants permission to accept a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions | List | ConfigurationAggregator* |  |
ListConformancePackComplianceScores | Grants permission to return the percentage of compliant rule-resource combinations in a conformance pack compared to the number of total possible rule-resource combinations | List |  |  |
ListDiscoveredResources | Grants permission to accept a resource type and returns a list of resource identifiers for the resources of that type | List |  |  |
ListResourceEvaluations | Grants permission to list the resource evaluation summaries for an AWS account in an AWS Region | List |  |  |
ListStoredQueries | Grants permission to list the stored queries for an AWS account in an AWS Region | List |  |  |
ListTagsForResource | Grants permission to list the tags for AWS Config resource | Read | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
ConformancePack |  |
OrganizationConfigRule |  |
OrganizationConformancePack |  |
StoredQuery |  |
PutAggregationAuthorization | Grants permission to authorize the aggregator account and region to collect data from the source account and region | Write | AggregationAuthorization* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigRule | Grants permission to add or update an AWS Config rule for evaluating whether your AWS resources comply with your desired configurations | Write | ConfigRule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigurationAggregator | Grants permission to create and update the configuration aggregator with the selected source accounts and regions | Write | ConfigurationAggregator* |  | iam:PassRole organizations:EnableAWSServiceAccess organizations:ListDelegatedAdministrators
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigurationRecorder | Grants permission to create a new configuration recorder to record the selected resource configurations | Write |  |  |
PutConformancePack | Grants permission to create or update a conformance pack | Write | ConformancePack* |  | iam:CreateServiceLinkedRole iam:PassRole s3:GetObject s3:ListBucket ssm:GetDocument
PutDeliveryChannel | Grants permission to create a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic | Write |  |  |
PutEvaluations | Grants permission to be used by an AWS Lambda function to deliver evaluation results to AWS Config | Write |  |  |
PutExternalEvaluation | Grants permission to deliver evaluation result to AWS Config | Write | ConfigRule* |  |
PutOrganizationConfigRule | Grants permission to add or update organization config rule for your entire organization evaluating whether your AWS resources comply with your desired configurations | Write | OrganizationConfigRule* |  | iam:CreateServiceLinkedRole iam:PassRole organizations:EnableAWSServiceAccess organizations:ListDelegatedAdministrators
PutOrganizationConformancePack | Grants permission to add or update organization conformance pack for your entire organization evaluating whether your AWS resources comply with your desired configurations | Write | OrganizationConformancePack* |  | iam:CreateServiceLinkedRole iam:PassRole organizations:EnableAWSServiceAccess organizations:ListDelegatedAdministrators s3:GetObject
PutRemediationConfigurations | Grants permission to add or update the remediation configuration with a specific AWS Config rule with the selected target or action | Write | RemediationConfiguration* |  | iam:PassRole
PutRemediationExceptions | Grants permission to add or update remediation exceptions for specific resources for a specific AWS Config rule | Write |  |  |
PutResourceConfig | Grants permission to record the configuration state for the resource provided in the request | Write |  |  |
PutRetentionConfiguration | Grants permission to create and update the retention configuration with details about retention period (number of days) that AWS Config stores your historical information | Write |  |  |
PutStoredQuery | Grants permission to save a new query or updates an existing saved query | Write | StoredQuery* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
SelectAggregateResourceConfig | Grants permission to accept a structured query language (SQL) SELECT command and an aggregator to query configuration state of AWS resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties | Read | ConfigurationAggregator* |  |
SelectResourceConfig | Grants permission to accept a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties | Read |  |  |
StartConfigRulesEvaluation | Grants permission to evaluate your resources against the specified Config rules | Write | ConfigRule* |  |
StartConfigurationRecorder | Grants permission to start recording configurations of the AWS resources you have selected to record in your AWS account | Write |  |  |
StartRemediationExecution | Grants permission to run an on-demand remediation for the specified AWS Config rules against the last known remediation configuration | Write |  |  | iam:PassRole
StartResourceEvaluation | Grants permission to evaluate your resource details against the AWS Config rules in your account | Write |  |  | cloudformation:DescribeType
StopConfigurationRecorder | Grants permission to stop recording configurations of the AWS resources you have selected to record in your AWS account | Write |  |  |
TagResource | Grants permission to associate the specified tags to a resource with the specified resourceArn | Tagging | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
ConformancePack |  |
OrganizationConfigRule |  |
OrganizationConformancePack |  |
StoredQuery |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to delete specified tags from a resource | Tagging | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
ConformancePack |  |
OrganizationConfigRule |  |
OrganizationConformancePack |  |
StoredQuery |  |
| aws:TagKeys |

## Resource types defined by AWS Config

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
AggregationAuthorization | `arn:$ { Partition}:config:$ { Region}:$ { Account}:aggregation-authorization/$ { AggregatorAccount}/$ { AggregatorRegion}` | aws:ResourceTag/${TagKey}
ConfigurationAggregator | `arn:$ { Partition}:config:$ { Region}:$ { Account}:config-aggregator/$ { AggregatorId}` | aws:ResourceTag/${TagKey}
ConfigRule | `arn:$ { Partition}:config:$ { Region}:$ { Account}:config-rule/$ { ConfigRuleId}` | aws:ResourceTag/${TagKey}
ConformancePack | `arn:$ { Partition}:config:$ { Region}:$ { Account}:conformance-pack/$ { ConformancePackName}/$ { ConformancePackId}` | aws:ResourceTag/${TagKey}
OrganizationConfigRule | `arn:$ { Partition}:config:$ { Region}:$ { Account}:organization-config-rule/$ { OrganizationConfigRuleId}` | aws:ResourceTag/${TagKey}
OrganizationConformancePack | `arn:$ { Partition}:config:$ { Region}:$ { Account}:organization-conformance-pack/$ { OrganizationConformancePackId}` | aws:ResourceTag/${TagKey}
RemediationConfiguration | `arn:$ { Partition}:config:$ { Region}:$ { Account}:remediation-configuration/$ { RemediationConfigurationId}` |
StoredQuery | `arn:$ { Partition}:config:$ { Region}:$ { Account}:stored-query/$ { StoredQueryName}/$ { StoredQueryId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Config

AWS Config defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource | String
aws:TagKeys | Filters access by the presence of mandatory tags in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.